var structPLStream =
[
    [ "alarm", "structPLStream.html#ae101c904156d069f592ae556c4ae5229", null ],
    [ "alt_unicode", "structPLStream.html#ad5b11c7d0725f7b465356a1230111389", null ],
    [ "arrow_fill", "structPLStream.html#a7ac1e3c7c8a4bafc756c2eda23a3e294", null ],
    [ "arrow_npts", "structPLStream.html#acdc0f21ca7d4639067884e64a7f56fae", null ],
    [ "arrow_x", "structPLStream.html#a015dd508317467f440062b7e1bdddb24", null ],
    [ "arrow_y", "structPLStream.html#ac334ee79d7d35de4e9298bfea47db84c", null ],
    [ "aspdev", "structPLStream.html#aa6d6f9587b12cd4133b172a93ae9d8c1", null ],
    [ "aspect", "structPLStream.html#a79d9ed2a822851f28285913cae12b840", null ],
    [ "aspori", "structPLStream.html#a3bc2ac0e93b21ffff11aba5de71571be", null ],
    [ "auto_path", "structPLStream.html#ad2ba4001e1e8e82da00e8c6011e2bafd", null ],
    [ "base3x", "structPLStream.html#a7668dd6c3144f760c74d391fb53accbe", null ],
    [ "base3y", "structPLStream.html#ac6604eb5ffb1439c89b1f40c812f7468", null ],
    [ "basecx", "structPLStream.html#a1cfe7c5e03bfc0b86f2b7890cbc89f18", null ],
    [ "basecy", "structPLStream.html#a777ec80e260e0df42be630ddf2d1f998", null ],
    [ "BaseName", "structPLStream.html#aa3615d1af2fac919072ca4e1ec079a95", null ],
    [ "bop_data", "structPLStream.html#ad60fe1add202f6c12ee8f6e3f4546962", null ],
    [ "bop_handler", "structPLStream.html#a570753f4964edc378661c79b56da7458", null ],
    [ "boxbb_xmax", "structPLStream.html#ad7882678b4080b91ab91bdb74759211a", null ],
    [ "boxbb_xmin", "structPLStream.html#ab37fa0272b8b6680de67e355dfff0f22", null ],
    [ "boxbb_ymax", "structPLStream.html#a7a075f5767e8505ff2ab5d2b0ad03fe1", null ],
    [ "boxbb_ymin", "structPLStream.html#a42239283478e0954e432bfaf0ee569f4", null ],
    [ "bufmax", "structPLStream.html#aed8924bacb8ff9e70b92493dcb91b17d", null ],
    [ "ButtonEH", "structPLStream.html#a4e9b2af1783d70f3958424b2ebd2b6e1", null ],
    [ "ButtonEH_data", "structPLStream.html#a0ebf6193b59ba88317034f0f5421a7cf", null ],
    [ "bytecnt", "structPLStream.html#a2bae14e39334897df7684da4a7d319fe", null ],
    [ "bytemax", "structPLStream.html#afa8cd5d4c8ac54d5308dc548991a3fee", null ],
    [ "caspfactor", "structPLStream.html#ae6456f977651a5e70b53ec8b18669ee1", null ],
    [ "cfont", "structPLStream.html#a8645356b1890060642f0b2076b62c82f", null ],
    [ "chrdef", "structPLStream.html#a8d7ce7ca2443356c163982d97066b112", null ],
    [ "chrht", "structPLStream.html#a6c335d8cba04eec1e566fe8cb570f5a6", null ],
    [ "clpxma", "structPLStream.html#ac6e99ff104e7775673bf6cc3a520151a", null ],
    [ "clpxmi", "structPLStream.html#ac1cb48c958c8a95ecb08a84106843953", null ],
    [ "clpyma", "structPLStream.html#a54d54311cae100f303fe6c1f74181639", null ],
    [ "clpymi", "structPLStream.html#a1579b4aa16d0d6656c60b6140d71bc29", null ],
    [ "cmap0", "structPLStream.html#a2cfea596db61b202941a2493c44fe609", null ],
    [ "cmap1", "structPLStream.html#abfb11a827bc7132ff5d27adde749912a", null ],
    [ "cmap1_max", "structPLStream.html#acfaba83b23c3137edac8768b9cc4dc59", null ],
    [ "cmap1_min", "structPLStream.html#a38aa4072d8dd697e1220bed77b4748e8", null ],
    [ "cmap1cp", "structPLStream.html#ad2c579c767880b5fd0a80be14c039411", null ],
    [ "color", "structPLStream.html#a52d57f1786f9f7f58de8eb4dd7eb331c", null ],
    [ "colorset", "structPLStream.html#adce35c7a87b6176fdb78008be0ea1ba3", null ],
    [ "coordinate_transform", "structPLStream.html#a9525e44053e2cc897d04d4d2cb620e98", null ],
    [ "coordinate_transform_data", "structPLStream.html#afafb813a77b59c40efe0a1fbea1ce9e1", null ],
    [ "curcmap", "structPLStream.html#a1cf50edb6a4244934c99af266c9e5605", null ],
    [ "curcolor", "structPLStream.html#a7ecc48aa20f228cb6ce457eb14bcb055", null ],
    [ "curel", "structPLStream.html#a51aa7168acf3743f95cd61cc25e32764", null ],
    [ "currx", "structPLStream.html#af7987521f0e181a4e6b409c0a8e7a112", null ],
    [ "curry", "structPLStream.html#a21dab6028add62839da70a7f1d59e350", null ],
    [ "cursub", "structPLStream.html#afa88c5619f1949843d31b00fdfc01ee1", null ],
    [ "cxx", "structPLStream.html#a82bae71839d89e15fcba93e7e4c61396", null ],
    [ "cxy", "structPLStream.html#ad4e738abac5a871bdaed7b6a4f35ab32", null ],
    [ "cyx", "structPLStream.html#ac2b4b92112494cf3f688df8454b9d407", null ],
    [ "cyy", "structPLStream.html#a77c7b2ab5ce1aedc6ed7c42a2ccd5fd8", null ],
    [ "cyz", "structPLStream.html#a451b8d8197b4b3c0463d31850e289141", null ],
    [ "czx", "structPLStream.html#a2938c215c56d483e30978a3088b472a3", null ],
    [ "czy", "structPLStream.html#a93b4567d7a2eb78eed5c40679a67d013", null ],
    [ "czz", "structPLStream.html#a894c2d246e4ee8436390975f2d28d16e", null ],
    [ "db", "structPLStream.html#a5b485e23de946ddaae43b13a71d120a2", null ],
    [ "debug", "structPLStream.html#a5083e76d7de0c5588dcb018bc2a82a37", null ],
    [ "delta", "structPLStream.html#aab6220efc877149ddaad3b45ea6cc9f7", null ],
    [ "dev", "structPLStream.html#abf8a6d71f35aeb854e3c75f5ed4f7679", null ],
    [ "dev_arc", "structPLStream.html#a263a03b7f7481ecf73b47b50821d3006", null ],
    [ "dev_clear", "structPLStream.html#a5ffd0f763c8d12a0912ebc4355377329", null ],
    [ "dev_compression", "structPLStream.html#a0b1b2bd10b03c184910e90aac79dddce", null ],
    [ "dev_dash", "structPLStream.html#a537ff4fef08a7f0978ac8f285739b54d", null ],
    [ "dev_data", "structPLStream.html#a64a27bd343528519bc7b9172ac9ae43b", null ],
    [ "dev_di", "structPLStream.html#ae84e24623a23d971c07e914557276808", null ],
    [ "dev_eofill", "structPLStream.html#ae43fbab5ba68a7c71f4cf5385178b2ff", null ],
    [ "dev_fastimg", "structPLStream.html#a7055c5f16dfa3de7f6c70fe69f846360", null ],
    [ "dev_fill0", "structPLStream.html#a36447d5d3f5bc8e6859c0b39308e4d6a", null ],
    [ "dev_fill1", "structPLStream.html#acb765112b653f0c3bf7e9fd716d2daed", null ],
    [ "dev_flush", "structPLStream.html#ad906fcb4939128aac6738460716b28ac", null ],
    [ "dev_gradient", "structPLStream.html#a753dd576c21893565997c66aa8d20b29", null ],
    [ "dev_hrshsym", "structPLStream.html#a3d7a7ea09e1f39e922122ab6a8837f71", null ],
    [ "dev_initialized", "structPLStream.html#a8c7933270949485ebbfe541d7bf45a06", null ],
    [ "dev_ix", "structPLStream.html#a980c6538d17d90c388a88453546fc663", null ],
    [ "dev_iy", "structPLStream.html#a95520c10ded8c43651b5757cb7ca15c0", null ],
    [ "dev_mem_alpha", "structPLStream.html#ab992021872cb743f34265ca2bd9388eb", null ],
    [ "dev_minor", "structPLStream.html#a8577d7d860e6d7cc45f33c28c06263c0", null ],
    [ "dev_modeset", "structPLStream.html#a4b68f6f1f7a47daa793141fbbea35470", null ],
    [ "dev_npts", "structPLStream.html#a47b274adf40a432cf4e95b4a54672199", null ],
    [ "dev_nptsX", "structPLStream.html#a766da98c5dceb23816632208aa2696b0", null ],
    [ "dev_nptsY", "structPLStream.html#ae2a1837b834853342917152d85a57c41", null ],
    [ "dev_swin", "structPLStream.html#ab85067bdc3a57afc4a2d3232eebf3b82", null ],
    [ "dev_text", "structPLStream.html#aa29bb1690b4fe47184b675881d98c272", null ],
    [ "dev_unicode", "structPLStream.html#a7ab92afcd83164c2633aa13f6056ef46", null ],
    [ "dev_x", "structPLStream.html#a6566af9cc819e25fbbf1cef193ef6696", null ],
    [ "dev_xor", "structPLStream.html#a88688e6248b7dbdcbcc637b50ff62ec7", null ],
    [ "dev_y", "structPLStream.html#a5442ed8975069a3962d3303fee4dcc2e", null ],
    [ "dev_z", "structPLStream.html#a9c5fe11361bfc214207b1bf769199780", null ],
    [ "dev_zmax", "structPLStream.html#aa1ab99774297abc47e0ae0a29b1c62fd", null ],
    [ "dev_zmin", "structPLStream.html#a6b267f89557ceef8790911bbb9062bb7", null ],
    [ "device", "structPLStream.html#aba76488f65f93041f7448fee09966b49", null ],
    [ "DevName", "structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe", null ],
    [ "diclpxma", "structPLStream.html#acc943d43125d39d5abdc7b66a53944a9", null ],
    [ "diclpxmi", "structPLStream.html#aedabf7549e134fb86674e4456e3b3313", null ],
    [ "diclpyma", "structPLStream.html#a97be1e95c2579b1fc3ed24da73601574", null ],
    [ "diclpymi", "structPLStream.html#a0d4efbdb77bab033d72bce77e20c8d15", null ],
    [ "didxax", "structPLStream.html#ab3ab79d4152a296f7c4f6c091cb77850", null ],
    [ "didxb", "structPLStream.html#acee55fef7a78d2e7da7eec5ab106d29f", null ],
    [ "didyay", "structPLStream.html#a308d6a478bf546f5216399da614540f9", null ],
    [ "didyb", "structPLStream.html#a3f01563d90fa5c2c07a43d03e47e2db5", null ],
    [ "difilt", "structPLStream.html#ac22c7ab738732908f042c0f7f631b505", null ],
    [ "dimxax", "structPLStream.html#ae8d1d27f3d9fc0282c0f0b5b3f233b42", null ],
    [ "dimxb", "structPLStream.html#a20f7c2bf90e325b365cecd8d2b402847", null ],
    [ "dimxmax", "structPLStream.html#a393f3edb7c450ed1d700620bd3c58def", null ],
    [ "dimxmin", "structPLStream.html#abbf615b9443c409fd54f64d7a08d11ab", null ],
    [ "dimxpmm", "structPLStream.html#a70512d186177200b25305e4d8613ebe9", null ],
    [ "dimyay", "structPLStream.html#aaec9ca24b4dc06ac9b0b2fa2ac7dbd8d", null ],
    [ "dimyb", "structPLStream.html#a74e66a6f996cbe9c004e9845daa94bba", null ],
    [ "dimymax", "structPLStream.html#ae38a604c5b068a4b46435f2271fe5ea2", null ],
    [ "dimymin", "structPLStream.html#a64abb742041bd2af0f4c4fb83602b03d", null ],
    [ "dimypmm", "structPLStream.html#a815964bc46df8351faefc688044709ed", null ],
    [ "diorot", "structPLStream.html#aff69cf352e07ab556f37a26d19a368fb", null ],
    [ "dioxax", "structPLStream.html#a001400d3e49aad07d1c89d414b200673", null ],
    [ "dioxay", "structPLStream.html#a179d0c392cf7a6684e54cb632b6ea225", null ],
    [ "dioxb", "structPLStream.html#a59ccd7403a647195e073b5764143ff49", null ],
    [ "dioyax", "structPLStream.html#a3f050b44ba82213a3dc63352ef328770", null ],
    [ "dioyay", "structPLStream.html#ad05baefb79b865c1324f07e035ecd07d", null ],
    [ "dioyb", "structPLStream.html#ab459504b6e9f6bb01e8a4f20dafb1a3b", null ],
    [ "dipxax", "structPLStream.html#a2cecc30bd1ca0277efc230aa1d4c7472", null ],
    [ "dipxb", "structPLStream.html#a13ef64a5b452b7d4d332379fbdf3ea10", null ],
    [ "dipxmax", "structPLStream.html#a4b10cf67465134426a6e0315cda0b5c9", null ],
    [ "dipxmin", "structPLStream.html#a99afd44759ce4c50812930c4114379f0", null ],
    [ "dipyay", "structPLStream.html#afd95befa6c0a9a9793dae9bcb8f7d6fb", null ],
    [ "dipyb", "structPLStream.html#a475ed8fb0364fba619527d49e0bcd1d8", null ],
    [ "dipymax", "structPLStream.html#a04323978cc4239d9dc14fc046242af7e", null ],
    [ "dipymin", "structPLStream.html#aa8af982530bc17c9ff924805c3c01aad", null ],
    [ "dispatch_table", "structPLStream.html#a887a3e2a4b6fa529050419fddea30a77", null ],
    [ "domxma", "structPLStream.html#a4c6dedc71895250e9ca0d1c06ff8332d", null ],
    [ "domxmi", "structPLStream.html#ac067cc75f47a42d588dc74194e0e0bc7", null ],
    [ "domyma", "structPLStream.html#a1a4d3ea4f87b7421f8e74f58c98ea866", null ],
    [ "domymi", "structPLStream.html#a5e0d0b52d8a39bceaca339e1d6f1396e", null ],
    [ "dp", "structPLStream.html#add8acf85b1d1d1800c8eb7df0535c400", null ],
    [ "eop_data", "structPLStream.html#a950595724cbec01e99598e620fcc07f4", null ],
    [ "eop_handler", "structPLStream.html#a000fbd25a6b6ae7375ae5523d58d01b0", null ],
    [ "errcode", "structPLStream.html#a50fa6ba427b0a21f46d09c161437a606", null ],
    [ "errmsg", "structPLStream.html#a36f05cb85d9aeda9116929013fbd519b", null ],
    [ "esc", "structPLStream.html#a57d0dd8fbd8c72d366d2c82113e64421", null ],
    [ "ext_resize_draw", "structPLStream.html#a488aca7a6aa773c995fde08251a6fb3e", null ],
    [ "famadv", "structPLStream.html#a15b0c38ac1073ccd572752bbca88642a", null ],
    [ "family", "structPLStream.html#a45e944722760a5e71145fcdde5de2988", null ],
    [ "fci", "structPLStream.html#ad5b9970ff24d3eadc87e039312e1e498", null ],
    [ "fflen", "structPLStream.html#aa7440a327d3574823524dd545fd47281", null ],
    [ "FileName", "structPLStream.html#a851b40b7643756cf9e7c998101bf3dfc", null ],
    [ "finc", "structPLStream.html#a052c6ef447de417a9670e6ee0dbfdd57", null ],
    [ "freeaspect", "structPLStream.html#a9c2d4f0ec960852d804de07c24ceca4f", null ],
    [ "FT", "structPLStream.html#ae3368cf4ce039d91f955ac2c1c365e8a", null ],
    [ "geometry", "structPLStream.html#a7844488c645193fee1f5e1f31df9798e", null ],
    [ "get_string_length", "structPLStream.html#a97ec49d30120b332e4f9246019bc9800", null ],
    [ "graphx", "structPLStream.html#ac97c1d9507b3b316c557f166eca17430", null ],
    [ "hack", "structPLStream.html#ac98930296aded0072e2beaeb4c8dcdbd", null ],
    [ "has_string_length", "structPLStream.html#abb61b1a584d5cbce8a389a7df736cd9b", null ],
    [ "icol0", "structPLStream.html#aefa321f4dc4061af6e3501067ea1e261", null ],
    [ "icol1", "structPLStream.html#a82d24cc3305adb04c1d1036df6003c77", null ],
    [ "if_boxbb", "structPLStream.html#a1fa5f252ec92f860303871f74cd2e83c", null ],
    [ "imclxmax", "structPLStream.html#ae8602851a062b3502489a0eb998a98fa", null ],
    [ "imclxmin", "structPLStream.html#a49ac52aee332a02ba789e0e5e69128c1", null ],
    [ "imclymax", "structPLStream.html#a76dd6806f6159ab000d8cddec24d6db5", null ],
    [ "imclymin", "structPLStream.html#acc97c3feefe13741d1db51a335da037a", null ],
    [ "inclin", "structPLStream.html#acfa6ee11c16dd92697e9bd04f7d8e7b2", null ],
    [ "initialized", "structPLStream.html#a637fa855165649caa179df813db19f7f", null ],
    [ "ipls", "structPLStream.html#a36bddf079f4266940159ffdba6830ce5", null ],
    [ "jx", "structPLStream.html#a679d1f6d61d384bbc6689c40aea9fb39", null ],
    [ "jy", "structPLStream.html#a516918f5d44640cbbd0bcd4712305281", null ],
    [ "KeyEH", "structPLStream.html#a855b9cd8ab925cccacad4ea057c12f8f", null ],
    [ "KeyEH_data", "structPLStream.html#af33021308e7252fc444851616dda077c", null ],
    [ "label_data", "structPLStream.html#ac9452129be862814a5f6f8077e57b595", null ],
    [ "label_func", "structPLStream.html#af4b069a524cea0e41228216a8ed92333", null ],
    [ "level", "structPLStream.html#acd3c7bd327b3301c1959ae2d6a16a5b3", null ],
    [ "line_style", "structPLStream.html#afea53ffa59a6a6e59edb4b79bf9f3189", null ],
    [ "linepos", "structPLStream.html#a91a227495bcc5009ee13647d77339dbc", null ],
    [ "LocateEH", "structPLStream.html#a8646f5179b4c58935ab68589634b2a49", null ],
    [ "LocateEH_data", "structPLStream.html#a46802dd3b80c5fcd380bd6245427981a", null ],
    [ "majdef", "structPLStream.html#aacf7dc5832d875092cda05b39b5bab87", null ],
    [ "majht", "structPLStream.html#aa2981115099d54a0bde1385b2f924ba1", null ],
    [ "mar", "structPLStream.html#ab8ac2cfcc7c89b3cb21006ec7090a73b", null ],
    [ "mark", "structPLStream.html#a79ee5c5d824a379d4f425f2b0f59b0ce", null ],
    [ "member", "structPLStream.html#a47c3d2d47d3c0b105beb0981c5634d15", null ],
    [ "mf_infile", "structPLStream.html#a8697ddd687cd34315ba3765b196a778d", null ],
    [ "mf_outfile", "structPLStream.html#afbc50e220f997c43679386a043a25ec2", null ],
    [ "mindef", "structPLStream.html#a3877166126904e55715aebbcf84e6ed6", null ],
    [ "minht", "structPLStream.html#ae7f22f1bf0f3acd6c4293c40bb8ac0a6", null ],
    [ "n_polygon", "structPLStream.html#a11fa5890f9ead979aa101e5ecea4373e", null ],
    [ "ncol0", "structPLStream.html#a2a4eb6dd4988edb03f34a5c835723e34", null ],
    [ "ncol1", "structPLStream.html#a12b0db426dab484e160ca6da6eca07e2", null ],
    [ "ncp1", "structPLStream.html#a1af010dee1309366628148acbcf73ae7", null ],
    [ "ngradient", "structPLStream.html#a1531435783b51f256577c2dbcaeee278", null ],
    [ "nms", "structPLStream.html#ac9113fe9b09e3ef9169e84ac6d9dd83d", null ],
    [ "nopause", "structPLStream.html#ad094de612997d072e9900f66fdf291da", null ],
    [ "nopixmap", "structPLStream.html#a58585cc53472acd8cd494bb076502867", null ],
    [ "nplwin", "structPLStream.html#a199959ddcfc50aa4fe416474c923872d", null ],
    [ "nps", "structPLStream.html#aad5cb9f9f1ca0595441867fce759b62a", null ],
    [ "nsubx", "structPLStream.html#ac761cd84fa6f9f804e444322eeedfce2", null ],
    [ "nsuby", "structPLStream.html#a884ca41c6992993a9f6af92d956803bd", null ],
    [ "original_chrdef", "structPLStream.html#a1c96071977b830441e8dc0b6d1ea0323", null ],
    [ "original_chrht", "structPLStream.html#ab8a4ab4b5ce5ed5892455da26b638af3", null ],
    [ "OutFile", "structPLStream.html#a60e06589a87b44963d348f430d7a6b24", null ],
    [ "output_type", "structPLStream.html#ab6a87dc559f780569957bdd96f586e2e", null ],
    [ "page", "structPLStream.html#a448034861d845f7a1357844d11e7fbe9", null ],
    [ "page_status", "structPLStream.html#a5000900b730320fb06805aa716802a64", null ],
    [ "pageset", "structPLStream.html#a3c6813b6a7faf7a444adf0338b280b27", null ],
    [ "patt", "structPLStream.html#a97e193646567fa5d487c29e16ee5c398", null ],
    [ "pdfs", "structPLStream.html#adbc1c6f49171693ded97033012fc5377", null ],
    [ "pendn", "structPLStream.html#a3c31ecd3a5fdf70ffd2cef5ce1e9ddf8", null ],
    [ "phyxlen", "structPLStream.html#ab486e5550932eed05f4d67642acfb322", null ],
    [ "phyxma", "structPLStream.html#af23066971554d9721b1c1d1a86d8e3b2", null ],
    [ "phyxmi", "structPLStream.html#ab74c69a6d7c33eac59b640e18607c2ba", null ],
    [ "phyylen", "structPLStream.html#a085b419f0ed385e70d076be15d6181f3", null ],
    [ "phyyma", "structPLStream.html#aa616b132f7f3a8b826a147be4161787a", null ],
    [ "phyymi", "structPLStream.html#a9d667e6d3c8c695daa1c62ffe2b39d98", null ],
    [ "plbuf_buffer", "structPLStream.html#a3f789e83127b6787146a9dace61718b6", null ],
    [ "plbuf_buffer_grow", "structPLStream.html#a1c3a8a26949c652d62c75025d0f51d0a", null ],
    [ "plbuf_buffer_size", "structPLStream.html#ab9e36ad9df32802d429079a114dfecfc", null ],
    [ "plbuf_read", "structPLStream.html#abb5e658588313b632a4bfc7a315fc0ec", null ],
    [ "plbuf_readpos", "structPLStream.html#a34c602d26ca76033d069d17587b854d6", null ],
    [ "plbuf_top", "structPLStream.html#a347f9faac2e393dd04e04d1efa45eac3", null ],
    [ "plbuf_write", "structPLStream.html#a5bb8768ffd553799be633be3ab70d915", null ],
    [ "plbufOwner", "structPLStream.html#aff218e325ec246a09fccdf84083462db", null ],
    [ "plPlotterPtr", "structPLStream.html#a9d81841ac0ad6a24645f9f04e115bf31", null ],
    [ "plserver", "structPLStream.html#a1b41113a10d760085aa3f61ee4313b59", null ],
    [ "plwin", "structPLStream.html#a77ff47b0b2433a55000be9791d845aef", null ],
    [ "plwindow", "structPLStream.html#a6ef609e12b8b5c9b9e151b8e8c441a06", null ],
    [ "portrait", "structPLStream.html#ac8562587fa9d5077836abfafc88cd8ca", null ],
    [ "precis", "structPLStream.html#aa0bbd34b62e61bcc154cd8844abcf7b7", null ],
    [ "program", "structPLStream.html#a896aa6409612b3db3cce8dda0a52e572", null ],
    [ "psdoc", "structPLStream.html#a1eabdffbd0bd29ae235b3e73a1bd2181", null ],
    [ "qsasconfig", "structPLStream.html#ad40603b323ee387492c98ea2fe967766", null ],
    [ "ranma", "structPLStream.html#aec2efdbc2ca51f988a82ce7ec78f0453", null ],
    [ "ranmi", "structPLStream.html#a9dba1033a4c746fca6c24651ec6db2f7", null ],
    [ "scale", "structPLStream.html#abfa28f6cc3addcf4409b19673a1a4aed", null ],
    [ "server_host", "structPLStream.html#af209d2135121f622b8ab68c2121d0bc2", null ],
    [ "server_name", "structPLStream.html#ac76f61228b7fb7dde6ddd15babcfefb7", null ],
    [ "server_nokill", "structPLStream.html#a51329d69da74c79dcafcc4e74df0b147", null ],
    [ "server_port", "structPLStream.html#a53853e0fdb3024f22697d71cbf1a0bd6", null ],
    [ "setpre", "structPLStream.html#aba86231507a869b8be29afcdb7b42b05", null ],
    [ "space", "structPLStream.html#a4e3572b37ae645577e7ef37debdb550d", null ],
    [ "spdxma", "structPLStream.html#afed4085b733e54c0ed12daa75a820cd0", null ],
    [ "spdxmi", "structPLStream.html#aa23805d34dad648d56f43794d4a5af87", null ],
    [ "spdyma", "structPLStream.html#af64224dcf1f55df50c24d9cffe8f54aa", null ],
    [ "spdymi", "structPLStream.html#a4d5687fcb26ffddde55c8c1fe9356f40", null ],
    [ "sppxma", "structPLStream.html#a99033016e00e950fd6350cd97a75cf91", null ],
    [ "sppxmi", "structPLStream.html#a21feedcbe1b56faa0b13a40e689873d9", null ],
    [ "sppyma", "structPLStream.html#a17c92912eb4f6041148061feeb5223b9", null ],
    [ "sppymi", "structPLStream.html#a3ca322e16fa00c0ddf52f92c3151eff2", null ],
    [ "stream_closed", "structPLStream.html#a5509f655765fadb9bd146dd1bd7c0ce3", null ],
    [ "string_length", "structPLStream.html#abcd74664b14cdd696b689a86a069ee8e", null ],
    [ "symdef", "structPLStream.html#a26607874d1df464949886828776bda07", null ],
    [ "symht", "structPLStream.html#a0d3c7b02bf7917634766b37f5745a748", null ],
    [ "termin", "structPLStream.html#aa97adea0a4b6cd5345ae40aaf63ea1f9", null ],
    [ "tidy", "structPLStream.html#a2062cf77b673f684970114b7e5e59a55", null ],
    [ "tidy_data", "structPLStream.html#a96af786417a69158fcad9232f4c6fb6e", null ],
    [ "timecnt", "structPLStream.html#ab566a389669a6fee28c910633ddd1bbc", null ],
    [ "timefmt", "structPLStream.html#a615a44564005f03825e17c780bdc9ff5", null ],
    [ "tk_file", "structPLStream.html#a8ba2e1a48efd7e725d71886d58c7a0ed", null ],
    [ "tmpcolor", "structPLStream.html#a7da43f464731362839688bb8fbc52969", null ],
    [ "umx", "structPLStream.html#abe2d9205f9174884d74a322c6cc78fe7", null ],
    [ "umy", "structPLStream.html#afd954dba26f50f0e747c8b6d8daf193f", null ],
    [ "user", "structPLStream.html#a2c45ef41fca4c2716c99b911c9c8d671", null ],
    [ "verbose", "structPLStream.html#a2218011a15ee0bdcd5fdd5163d25d954", null ],
    [ "vpdxma", "structPLStream.html#a70f57c71ace3618b3d393496450096f3", null ],
    [ "vpdxmi", "structPLStream.html#a8d7fc700a977b22e669939c96dcb24fc", null ],
    [ "vpdyma", "structPLStream.html#acf6d7c8a591d67fcdef0dd07e00c6cf3", null ],
    [ "vpdymi", "structPLStream.html#a6d63bdc61fc7bf5f3328e31df9cff1d2", null ],
    [ "vppxma", "structPLStream.html#aa6c4b778304c44688e3bfee6b24ece84", null ],
    [ "vppxmi", "structPLStream.html#ae2b822caa7597bbf6158104568d4ff14", null ],
    [ "vppyma", "structPLStream.html#a20e110cfacd22bf3f85bb0d1ba81e324", null ],
    [ "vppymi", "structPLStream.html#a3be05ca8e59d93438f257e19eb2cbd68", null ],
    [ "vpwxma", "structPLStream.html#a0c3a6a8d591229bf49231b4a6c127730", null ],
    [ "vpwxmi", "structPLStream.html#aa327cbb591b00e5f6be66c40e7eabea4", null ],
    [ "vpwyma", "structPLStream.html#ab648c79121e511ce3fc6be88b8de9c23", null ],
    [ "vpwymi", "structPLStream.html#a2bbfa128180249ba951262bc3bd7ab1e", null ],
    [ "wdxoff", "structPLStream.html#a6916b03e47be96ff859874fa15f98fa6", null ],
    [ "wdxscl", "structPLStream.html#a36fef6d794ee3daeb1e22fb9552d499a", null ],
    [ "wdyoff", "structPLStream.html#a732b5abcb2edb9375695bd9c61e98272", null ],
    [ "wdyscl", "structPLStream.html#a1ddb0104b923970d0889e9bcb9820aef", null ],
    [ "width", "structPLStream.html#a5ee6732e0c80f6ee27d5588100f07cb7", null ],
    [ "widthlock", "structPLStream.html#a91babbdc474e6a01e602ad5d21c58710", null ],
    [ "widthset", "structPLStream.html#a812c6e5e4d84453944c67784f43b2411", null ],
    [ "window_id", "structPLStream.html#a209b4e2760c7744dcc04912330249551", null ],
    [ "wmxoff", "structPLStream.html#aea4c297c42f3e7e2d3fd21dee421d53a", null ],
    [ "wmxscl", "structPLStream.html#ab4124f5acbd397314da02d08f6e29174", null ],
    [ "wmyoff", "structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1", null ],
    [ "wmyscl", "structPLStream.html#a5a70268fa1d38b34ccf0a3336f58de0a", null ],
    [ "wpxoff", "structPLStream.html#a28fc8e7991a0824a135450fca3304966", null ],
    [ "wpxscl", "structPLStream.html#a3f07edd33b6774ecc1e1a5df3e7e7072", null ],
    [ "wpyoff", "structPLStream.html#afb689ff0653205319126b01be493409f", null ],
    [ "wpyscl", "structPLStream.html#a386fb51e8daea7f899c61edd02b589be", null ],
    [ "x_polygon", "structPLStream.html#a642f1db20ff569a772ee88762d9671c6", null ],
    [ "xdigits", "structPLStream.html#ae74914a0b58f1d8315ed2c72fae2f6f5", null ],
    [ "xdigmax", "structPLStream.html#abe70e4b3e2130f7a25e67c9b49c70ad8", null ],
    [ "xdpi", "structPLStream.html#a2d24d9a093f447144c8f3ea9cac2d349", null ],
    [ "xgradient", "structPLStream.html#a962465c1e71ed607052e2a1e36d0b4b5", null ],
    [ "xlength", "structPLStream.html#ac3040626ec1dc9a402d30722ecb33bf1", null ],
    [ "xoffset", "structPLStream.html#a59aa7205e849ddd9b67c95420bf3bffe", null ],
    [ "xpmm", "structPLStream.html#af2865bcc032aafba071341ba183d6c39", null ],
    [ "y_polygon", "structPLStream.html#a3f3f8d108bba28815dab3b47487d0be6", null ],
    [ "ydigits", "structPLStream.html#a3a0de4e6e2308cccbfde404e8b33e00a", null ],
    [ "ydigmax", "structPLStream.html#a8afb1961b042d017d6a2e1f55048efcb", null ],
    [ "ydpi", "structPLStream.html#ad5e311f234f326dbf0c2ce5daa254168", null ],
    [ "ygradient", "structPLStream.html#ad93a718bb0f9604e436f6622a7501755", null ],
    [ "ylength", "structPLStream.html#a25c35ad1adb25dba0c1e7489056cc2a7", null ],
    [ "yoffset", "structPLStream.html#a64fb80627567ef6169eec2f693677384", null ],
    [ "ypmm", "structPLStream.html#ad576a601d6561fd20fcbdb176ad5e538", null ],
    [ "zdigits", "structPLStream.html#ad99012942cfb2f0faa693f804bf3f170", null ],
    [ "zdigmax", "structPLStream.html#a25e36a883de1f3f5982d0cf7c7b78210", null ],
    [ "zzscl", "structPLStream.html#afcda1a9b7657f4bb2f7585c131a17976", null ]
];